.TH BABEL 8
.SH NAME
babel \- ad-hoc network routing daemon
.SH SYNOPSIS
.B babel
.IR option ...
[
.B \-\-
] [
.I id
]
.IR interface ...
.SH DESCRIPTION
Babel is a loop-avoiding distance-vector routing protocol roughly
based on DSDV and AODV, but with provisions for link cost estimation
and redistribution of routes from other routing protocols.

While it is optimised for wireless mesh networks, Babel will also work
efficiently on wired networks.
.SH OPTIONS
.TP
.BI \-m " multicast-address"
Specify the link-local multicast address to be used by the protocol.
.TP
.BI \-p " port"
Specify the UDP port number to be used by the protocol.
.TP
.BI \-S " state-file"
Set the name of the file used for preserving long-term information
between invocations of the
.B babel
daemon.  If this file is deleted, the daemon will run in passive mode
for 3 minutes when it is next started (see
.B -P
below), and other hosts might initially ignore it.  The default is
.BR /var/lib/babel-state .
.TP
.BI \-h " hello-interval"
Specify the interval in seconds at which scheduled hello packets are
sent on wireless interfaces.  The default is 4 seconds.
.TP
.BI \-H " wired-hello-interval"
Specify the interval in seconds at which scheduled hello packets are
sent on wired interfaces.  The default is 20 seconds.
.TP
.BI \-i " idle-hello-interval"
Enable detection of idle networks (networks on which we haven't
accepted a hello packet in 5 minutes) and specify the interval in
seconds at which scheduled hello packets are sent on idle interfaces.
This functonality is experimental, don't use it unless you know what
you are doing.
.TP
.BI \-u " update-interval"
Specify the interval in seconds at which scheduled routing table dumps
are made on all interfaces.  The default is either 5 times the
wireless hello interval, twice wired hello interval, or 70 seconds,
whichever is less.  Babel uses triggered updates in addition to
scheduled updates, so this value may be set to a fairly large value.
.TP
.BI \-k " kernel-metric"
Specify a value that will be added to routes' metrics before
installing them in the kernel; this is useful when a single node
participates in multiple routing protocols.  The default is 0.
.TP
.B \-l
Use IFF_RUNNING (carrier sense) when determining interface availability.
.TP
.B \-w
Don't optimise wired links, assume all interfaces are wireless.
.TP
.B \-s
Do not perform split-horizon processing on wired interfaces.
Split-horizon is never performed on wireless interfaces.
.TP
.B \-P
Run in parasitic (passive) mode.  The daemon will only announce
redistributed routes.
.TP
.BI \-d " level"
Debug level.  A value of 1 requests a routing table dump at every
iteration through the daemon's main loop.  A value of 2 additionally
requests tracing every message sent or received.  A value of
3 additionally dumps all interactions with the OS kernel.  The default
is 0.
.TP
.BI \-g " port"
Listen for connections from a front-end on port
.IR port .
.TP
.BI \-t " table"
Use the given kernel routing table for routes inserted by Babel.
.TP
.BI \-T " table"
Export routes from the given kernel routing table.
.TP
.BI \-c " filename"
Specify the name of the configuration file.  The default is
.BR /etc/babel.conf .
.TP
.B \-D
Daemonise at startup.
.TP
.BI \-L " logfile"
Specify a file to log random ``how do you do?'' messages to.  This
defaults to standard error if not daemonising, and to
.B /var/log/babel.log
otherwise.
.TP
.BI \-I " pidfile"
Specify a file to write our process id to.
.TP
.RI "[ " id " ]"
The router-id of this daemon.  This should normally be an IPv6 or IPv4
address of this machine, but can be any unique 128-bit string.  If
omitted, Babel will try to determine a suitable router-id automatically.
.TP
.IR interface ...
The list of interfaces on which the protocol should operate.
.SH METRICS
.B Babel
manipulates costs and metrics that are 16-bit unsigned integers, with
the value 65535 representing infinity.  A cost of 256 is interpreted
as a wireless hop with no packet losses.  A cost of 255 or less is
interpreted as a wired link.
.SH CONFIG FILE FORMAT
The configuration file is a sequence of lines each of which specifies
a filter entry.  Each of these lines has the following format:
.IP
.I filter selector... action
.PP
.I Filter
specifies the filter to which this entry will be added, and can be one of
.BR in ,
.BR out ,
or
.BR redistribute .

.I Selector
specifies the conditions under which the given statement matches.  It
can be one of
.TP
.BI ip " prefix"
This entry only applies to routes in the given prefix.
.TP
.BI eq " plen"
This entry only applies to routes with a prefix length equal to
.BR plen .
.TP
.BI le " plen"
This entry only applies to routes with a prefix length less or equal to
.BR plen .
.TP
.BI ge " plen"
This entry only applies to routes with a prefix length greater or equal to
.BR plen .
.TP
.BI neigh " id"
This entry only applies to routes learned from a neighbour with router-id
.IR id .
.TP
.BI id " id"
This entry only applies to routes originated by a router with router-id
.IR id .
.TP
.BI proto " p"
This entry only applies to kernel routes with kernel protocol number
.IR p .
If neither
.B proto
nor
.B local
is specified, this entry applies to all non-local kernel routes.
.TP
.B local
This entry only applies to local addresses.
.TP
.BI if " interface"
For an input filter, this specifies the interface over which the route
is learned.  For an output filter, this specifies the interface over
which this route is advertised.  For a redistribute statement, this
specifies the interface over which the route forwards packets.
.PP
.I Action
specifies the action to be taken when this entry matches.  It can have
one of the following values:
.TP
.B allow
Allow this route, without changing its metric (or setting its metric
to 0 in case of a redistribute filter).
.TP
.B deny
Ignore this route.
.TP
.BI metric " value"
For an input or output filter, allow this route after increasing its metric by
.IR value .
For a redistribute filter, redistribute this route with metric
.IR value .
.PP
If
.I action
is not specified, it defaults to
.BR allow .

By default,
.B Babel
redistributes all local addresses, and no other routes.  In order to
make sure that only the routes you specify are redistributed, you
should include the line
.IP
redistribute local deny
.PP
as the last line in your configuration file.

.SH EXAMPLES
You can participate in a Babel mesh network by simply running
.IP
# babel \-C 'redistribute local' eth1
.PP
where
.B eth1
is your wireless interface.

In order to gateway between multiple interfaces, just list them all on
the command line:
.IP
# babel \-C 'redistribute local' eth1 eth0 sit1
.PP
On an access point, you'll probably want to redistribute some external
routes into Babel:
.IP
# babel \\
    \-C 'redistribute local' \\
    \-C 'redistribute metric 256' \\
    eth1
.PP
or, if you want to constrain the routes that you redistribute,
.IP
# babel \\
    \-C 'redistribute local' \\
    \-C 'redistribute proto 11 ip ::/0 le 64 metric 256' \\
    \-C 'redistribute proto 11 ip 0.0.0.0/0 le 24 metric 256' \\
    eth1
.PP
.SH WIRED INTERFACES
By default, the daemon optimises traffic on wired interfaces by
sending fewer scheduled hello messages and performing split-horizon
processing.  These optimisations can be disabled by using the
.B \-H
and
.B \-s
options respectively.

No link cost estimation is ever performed on wired interfaces: a wired
adjacency is assumed to be up if at least two of the last three hello
messages have been received, and down otherwise.

All of these optimisations can be disabled by using the
.B \-w
flag.
.SH FILES
.TP
.B /etc/babel.conf
The default location of the configuration file.
.TP
.B /var/lib/babel\-state
The default location of the file storing long-term state.
.TP
.B /var/log/babel.log
The default location of the log file.
.SH SIGNALS
.TP
.B SIGUSR1
Dump Babel's routing tables to standard output or to the log file.
.TP
.B SIGUSR2
Check interfaces and kernel routes right now, then reopen the log file.
.SH SECURITY
Babel is a completely insecure protocol: any attacker able to inject
IP packets with a link-local source address can disrupt the protocol's
operation.  This is no different from unsecured neighbour discovery
(ARP in IPv4).

Since Babel uses link-local addresses only, there is no need to update
firewalls to allow forwarding of Babel protocol packets.  If local
filtering is being done, UDP datagrams to the port used by the
protocol should be allowed.  As Babel uses unicast packets in some
cases, it is not enough to just allow packets destined to Babel's
multicast address.
.SH BUGS
Plenty.  This is experimental software, run at your own risk.
.SH SEE ALSO
.BR routed (8),
.BR route6d (8),
.BR zebra (8),
.BR ahcpd (8).
.SH AUTHOR
Juliusz Chroboczek.
